@@ -22,6 +22,7 @@
 #' @param object An instance of one of the classes listed above.
 #' @param levels If TRUE, report results in levels. If FALSE, report results in percents. Default is FALSE.
 #' @param market If TRUE, calculates (post-merger) share-weighted average of metric. Default is FALSE.
+#' @param party If TRUE, calculates (post-merger) share-weighted average of metric for merging parties. Default is FALSE.
 #' @param index If "paasche",calculates market-wide price changes using post-merger predicted shares. If  "laspeyres", 
 #' calculates price index using pre-merger shares. Default is "paasche".
 #' @param isMax If TRUE, uses numerical derivatives to determine if
@@ -42,8 +43,7 @@ NULL
 
 setGeneric (
   name= "calcPriceDelta",
-  def=function(object,levels = FALSE, market = FALSE,...){standardGeneric("calcPriceDelta")}
-)
+  def=function(object,levels = FALSE, market = FALSE, party = FALSE, isMax=FALSE,index=c("paasche","laspeyres"),...){standardGeneric("calcPriceDelta")},signature="object")
 
 ## Method to compute price changes
 #'@rdname PriceDelta-Methods
@@ -51,7 +51,7 @@ setGeneric (
 setMethod(
   f= "calcPriceDelta",
   signature= "Antitrust",
-  definition=function(object, levels = FALSE, market = FALSE, index=c("paasche","laspeyres"), ...  ){
+  definition=function(object, levels = FALSE, market = FALSE, party = FALSE, index=c("paasche","laspeyres"), ...  ){
 
     index <- match.arg(index)
     
@@ -63,7 +63,7 @@ setMethod(
     else{priceDelta <- pricePost/pricePre - 1}
     #names(priceDelta) <- object@labels
 
-    if(market){
+    if(market || party){
       
       sharesPre <- calcShares(object, preMerger=TRUE,revenue=FALSE,...)
       sharesPre <- sharesPre/sum(sharesPre,na.rm=TRUE)
@@ -72,6 +72,19 @@ setMethod(
       sharesPost <- sharesPost/sum(sharesPost,revenue=FALSE,na.rm=TRUE)
       
       
+      
+      if(party){
+        ownerPre <- ownerToMatrix(object,preMerger=TRUE)
+        ownerPost <-ownerToMatrix(object,preMerger=FALSE)
+        
+        isParty <- rowSums( abs(ownerPost - ownerPre))>0
+        sharesPre <- sharesPre[isParty]
+        sharesPost <- sharesPost[isParty]
+        pricePre <- pricePre[isParty]
+        pricePost <- pricePost[isParty]
+        
+      }
+      
       if(index=="paasche")  priceDelta <- sum(sharesPost*pricePost)/sum(sharesPost*pricePre) - 1
       else if (index=="laspeyres")  priceDelta <- sum(sharesPre*pricePost)/sum(sharesPre*pricePre) - 1
       
@@ -106,6 +119,8 @@ setMethod(
     
     up <- object@up
     down <- object@down
+    
+    chain_level <- object@chain_level
 
     marginsPre <- calcMargins(object,preMerger=TRUE,level=TRUE)
     marginsPost <- calcMargins(object,preMerger=FALSE,level=TRUE)
@@ -139,7 +154,9 @@ setMethod(
     
       upDelta <- marginsPost$up - marginsPre$up + mcDeltaUp
       downDelta <- marginsPost$down - marginsPre$down + mcDeltaDown
-    
+      
+      if(chain_level =="retailer") upDelta <-rep(0,length(upDelta)) 
+      else if(chain_level =="wholesaler") downDelta <-rep(0,length(downDelta))
       upPricePre <- up@pricePre
       downPricePre <- down@pricePre
     }
@@ -165,6 +182,9 @@ setMethod(
       upDelta <- sum(upDelta,na.rm=TRUE)
       downDelta <- sum(downDelta,na.rm=TRUE)
       
+      if(chain_level =="retailer") upDelta <-0
+      else if(chain_level =="wholesaler") downDelta <- 0
+      
       upPricePre <- sum(upPricePre,na.rm=TRUE)
       downPricePre <- sum(downPricePre,na.rm=TRUE)
     }
@@ -187,16 +207,34 @@ setMethod(
 setMethod(
   f= "calcPriceDelta",
   signature= "AIDS",
-  definition=function(object,isMax=FALSE,levels=FALSE,subset,market=FALSE, index=c("paasche","laspeyres"),...){
+  definition=function(object,levels=FALSE,market=FALSE,party=FALSE,isMax=FALSE, index=c("paasche","laspeyres"),subset,...){
 
     index <- match.arg(index)
     
-    if(market){
+  
+    priceDelta <- object@priceDelta 
+
       
+  if (market || party){
+    
+    if(!is.null(object@pricePre) && all(!is.na(object@pricePre))){
+      result <- callNextMethod()
+      return(result)
+    }
+    
+    if(party){
       if(index=="paasche") shares <-  calcShares(object, preMerger = FALSE)
       else{shares <-  calcShares(object, preMerger = TRUE)}
+      
+      
+      isParty <- rowSums( abs(object@ownerPost - object@ownerPre))>0
+      priceDelta <- priceDelta[isParty]
+      shares <- shares[isParty]
+    }
     
-      return(sum(object@priceDelta * shares,na.rm=TRUE))
+
+     
+      return(sum( priceDelta * shares,na.rm=TRUE))
            }
 
     ownerPost <- object@ownerPost
@@ -266,9 +304,11 @@ setMethod(
 setMethod(
   f= "calcPriceDelta",
   signature= "Auction2ndLogit",
-  definition=function(object,levels=TRUE, market=FALSE,exAnte=ifelse(market,TRUE,FALSE),...){
+  definition=function(object,levels=TRUE, market=FALSE,party=FALSE,exAnte=ifelse(market,TRUE,FALSE),...){
 
-    if(!levels){
+    output <- object@output
+    
+    if(all(!is.na(object@pricePre)) || !levels){
       result <- callNextMethod()
       return(result)
     }
@@ -279,7 +319,7 @@ setMethod(
 
 
     
-    if(exAnte){
+    if(exAnte || market || party){
       sharesPost <- calcShares(object, preMerger=FALSE)
       mcDelta <- mcDelta*sharesPost
     }
@@ -287,11 +327,17 @@ setMethod(
     result <- calcMargins(object, preMerger=FALSE,exAnte=exAnte) + mcDelta -
       calcMargins(object, preMerger=TRUE,exAnte=exAnte)
 
+    if(!output) result <- -1*result
+    
     if(market) result <- sum(result,na.rm=TRUE)
+    if(party){
+      isParty <- rowSums( abs(object@ownerPost - object@ownerPre))>0
+      result <- sum(result[isParty],na.rm=TRUE)
+    }
     
  
 
-    if(!market) names(result) <- object@labels
+    if(!market && !party) names(result) <- object@labels
     
     return(result)
   }
