@@ -113,7 +113,10 @@ setMethod(
 
 
     priceStart <- object@priceStart
-
+    output    <-  object@output
+    outSign <- ifelse(output,-1,1)
+    alpha <- object@slopes$alpha
+    
     if(preMerger){
       owner <- object@ownerPre
       mc    <- object@mcPre
@@ -147,11 +150,11 @@ setMethod(
       else{          object@pricePost[subset] <- priceCand}
 
 
-      margins   <- 1 - mc/priceCand
-      revenues  <- calcShares(object,preMerger,revenue=TRUE)[subset]
-      elasticities     <- t(elast(object,preMerger)[subset,subset])
-
-      thisFOC <- revenues * diag(owner) + as.vector((elasticities * owner) %*% (margins * revenues))
+      if(output){margins   <- priceCand - mc}
+      else{margins   <- mc - priceCand}
+      predMargin <- calcMargins(object,preMerger,level=TRUE)[subset]
+      
+      thisFOC <- margins - predMargin
 
       return(thisFOC)
     }
@@ -191,7 +194,8 @@ setMethod(
   definition=function(object,preMerger=TRUE,exAnte=FALSE){
 
     nprods <- length(object@shares)
-
+    output <- object@output
+    
     if(preMerger){
       owner <- object@ownerPre
       mc <- object@mcPre
@@ -202,8 +206,11 @@ setMethod(
 
     margins <- calcMargins(object,preMerger,exAnte=FALSE)
 
-    prices <- margins + mc
+    
 
+    if(output){prices <- margins + mc}
+    else{prices <- mc - margins }
+    
     if(exAnte){
 
 
@@ -225,7 +232,7 @@ setMethod(
   definition=function(object,preMerger=TRUE,isMax=FALSE,subset,...){
 
 
-
+    output <- object@output
 
     if(preMerger){
       owner <- object@ownerPre
@@ -262,7 +269,10 @@ setMethod(
       else{          object@pricePost[subset] <- priceCand}
 
 
-      margins          <- 1 - mc/priceCand
+      
+      if(output){margins   <- 1 - mc/priceCand}
+      else{margins   <- mc/priceCand - 1}
+      
       revenues         <- calcShares(object, preMerger = preMerger, revenue = TRUE)
       quantities       <- calcQuantities(object, preMerger = preMerger)
       revenues         <- revenues[subset]
@@ -566,6 +576,12 @@ setMethod(
     
     up <- object@up
     down <- object@down
+    
+    chain_level <- object@chain_level
+    
+    upPricePre <- up@prices
+    downPricePre <- down@prices
+    
     #isHorizontal <- object@isHorizontal
     
     
@@ -573,10 +589,18 @@ setMethod(
     alpha <- down@slopes$alpha
     meanval <- down@slopes$meanval[subsetDown]
     
-    
     priceStartUp <- up@priceStart
     priceStartDown <- down@priceStart
+    
+    if(chain_level == "full"){
     priceStart <- c(priceStartUp[subsetDown],priceStartDown[subsetDown])
+    }
+    else if (chain_level =="retailer"){
+      priceStart <- priceStartDown[subsetDown]
+    }
+    else if (chain_level =="wholesaler"){
+      priceStart <- priceStartUp[subsetDown]
+    }
     
     
     nprods <- length(meanval)
@@ -622,9 +646,24 @@ setMethod(
        
         
       thisobj <- object
-      priceCandUp= rep(NA, 1,nprods)[subsetDown] 
-      priceCandUp <- priceCand[1:length(priceCandUp)]
-      priceCandDown <- priceCand[-(1:length(priceCandUp))]
+      
+      
+      if(chain_level == "full"){
+        priceCandUp= rep(NA, 1,nprods)[subsetDown] 
+        priceCandUp <- priceCand[1:length(priceCandUp)]
+        priceCandDown <- priceCand[-(1:length(priceCandUp))]
+        
+      }
+      else if (chain_level =="retailer"){
+        priceCandUp = up@prices[subsetDown]
+        priceCandDown = priceCand
+      }
+      else if (chain_level =="wholesaler"){
+        priceCandDown = down@prices[subsetDown]
+        priceCandUp = priceCand
+      }
+      
+      
       
       if(preMerger){ 
         up@pricePre <- priceCandUp
@@ -664,6 +703,10 @@ setMethod(
       
       thisFOC= c(upFOC,downFOC)
       
+      if(chain_level == "full"){thisFOC= c(upFOC,downFOC)}
+      else if (chain_level == "retailer"){thisFOC = downFOC}
+      else if (chain_level == "wholesaler"){thisFOC = upFOC}
+      
       return(thisFOC)
     }
     
@@ -679,9 +722,24 @@ setMethod(
       
         
         
-      minResultUp[subsetDown] <- minResult[1:length(priceStartUp[subsetDown])] 
-      minResultDown[subsetDown] <- minResult[-(1:length(priceStartUp[subsetDown]))]
+      
     
+      if(chain_level == "full"){
+        minResultUp[subsetDown] <- minResult[1:length(priceStartUp[subsetDown])] 
+        minResultDown[subsetDown] <- minResult[-(1:length(priceStartUp[subsetDown]))]
+        
+      }
+      else if (chain_level =="retailer"){
+        minResultUp[subsetDown] <- upPricePre[subsetDown]
+        minResultDown[subsetDown] <- minResult
+       
+      }
+      else if (chain_level =="wholesaler"){
+        minResultUp[subsetDown] <- minResult
+        minResultDown[subsetDown] <- downPricePre[subsetDown]
+        
+      }
+      
    
       return(list(up=minResultUp,down=minResultDown)) 
   }
